import { Suspense, lazy } from "react";
import { Toaster } from "@/components/ui/toaster";
import { Toaster as Sonner } from "@/components/ui/sonner";
import { TooltipProvider } from "@/components/ui/tooltip";
import { QueryClient, QueryClientProvider } from "@tanstack/react-query";
import { BrowserRouter, Routes, Route } from "react-router-dom";
import { useUser } from "@clerk/clerk-react";
import { useAutoOrganization } from "@/hooks/useAutoOrganization";
import { CurrencyProvider } from "@/contexts/CurrencyContext";
import { LoadingFallback } from "@/components/LoadingFallback";

// Lazy load pages for better performance
const Index = lazy(() => import("./pages/Index"));
const Dashboard = lazy(() => import("./pages/Dashboard"));
const Projects = lazy(() => import("./pages/Projects"));
const NewProject = lazy(() => import("./pages/NewProject"));
const ProjectDetail = lazy(() => import("./pages/ProjectDetail"));
const Contracts = lazy(() => import("./pages/Contracts"));
const Finances = lazy(() => import("./pages/Finances"));
const Settings = lazy(() => import("./pages/Settings"));
const AdvancedReports = lazy(() => import("./pages/AdvancedReports"));
const CustomReports = lazy(() => import("./pages/CustomReports"));
const NotFound = lazy(() => import("./pages/NotFound"));
const AdminPanel = lazy(() => import("./pages/AdminPanel"));

// Client view (no auth required)
const ClientProjectView = lazy(() => import("./pages/ClientProjectView"));


// Legal pages
const Privacy = lazy(() => import("./pages/legal/Privacy"));
const Terms = lazy(() => import("./pages/legal/Terms"));
const Cookies = lazy(() => import("./pages/legal/Cookies"));

// Support pages
const Help = lazy(() => import("./pages/support/Help"));
const Contact = lazy(() => import("./pages/support/Contact"));

// Company pages
const About = lazy(() => import("./pages/About"));
const Blog = lazy(() => import("./pages/Blog"));
const Careers = lazy(() => import("./pages/Careers"));

const queryClient = new QueryClient();

const AppContent = () => {
  const { isSignedIn } = useUser();
  
  useAutoOrganization();

  return (
    <BrowserRouter>
      <Suspense fallback={<LoadingFallback message="Loading page..." />}>
        <Routes>
          <Route path="/" element={<Index />} />
          <Route path="/dashboard" element={<Dashboard />} />
          <Route path="/projects" element={<Projects />} />
          <Route path="/projects/new" element={<NewProject />} />
          <Route path="/projects/:id" element={<ProjectDetail />} />
          <Route path="/contracts" element={<Contracts />} />
          <Route path="/finances" element={<Finances />} />
          <Route path="/settings" element={<Settings />} />
        <Route path="/reports/advanced" element={<AdvancedReports />} />
        <Route path="/reports/custom" element={<CustomReports />} />
          
          {/* Public client project view */}
          <Route path="/client/project/:clientViewId" element={<ClientProjectView />} />
          
          
          {/* Legal pages */}
          <Route path="/legal/privacy" element={<Privacy />} />
          <Route path="/legal/terms" element={<Terms />} />
          <Route path="/legal/cookies" element={<Cookies />} />
          
          {/* Support pages */}
          <Route path="/support/help" element={<Help />} />
          <Route path="/support/contact" element={<Contact />} />
          
          {/* Company pages */}
          <Route path="/about" element={<About />} />
          <Route path="/blog" element={<Blog />} />
          <Route path="/careers" element={<Careers />} />
          
          {/* Admin Panel - Hidden route */}
          <Route path="/admin-panel" element={<AdminPanel />} />
          
          {/* Catch-all route */}
          <Route path="*" element={<NotFound />} />
        </Routes>
      </Suspense>
    </BrowserRouter>
  );
};

const App = () => (
  <QueryClientProvider client={queryClient}>
    <TooltipProvider>
      <CurrencyProvider>
        <Toaster />
        <Sonner />
        <AppContent />
      </CurrencyProvider>
    </TooltipProvider>
  </QueryClientProvider>
);

export default App;
